==> wordsonline_connector-1.0.21-alpha8.tar.gz: wordsonline_connector/js/job_form.js <==
function onContentTypeChange(obj) {

    if (obj) {
        let val = obj.value;
        let data = JSON.parse(obj.getAttribute("service-level-data"));
        let select = document.getElementsByName("settings[service_level]");
        if (select) {
            let defaultVal =select[0].getAttribute("default-value");
            const count = select[0].options.length;
            // for (let i = count - 1; i >= 0; i--) {
            //     select[0].options.remove(i);
            // }
            // let arr = [];
            // for (let index = 0; index < data.length; index++) {
            //     let element = data[index];
            //     if (element['contentType'] == val && arr.indexOf(element['serviceName']) < 0) {
            //         arr.push(element['serviceName']);
            //         var opt = document.createElement('option');
            //         opt.value = element['serviceName'];
            //         opt.innerHTML = element['serviceName'];
            //         if(defaultVal && defaultVal !=null && defaultVal!="" && defaultVal == opt.value){
            //           opt.setAttribute('selected', 'selected');
            //         }
            //         select[0].appendChild(opt);
            //     }
            // }
            for (let i = count - 1; i >= 0; i--) {
                for (let index = 0; index < data.length; index++) {
                    let element = data[index];
                    if (element['contentType'] == val) {
                        if(select[0].options[i].value == element['serviceName']){
                            select[0].options[i].style.display ="block";
                            if(defaultVal && defaultVal !=null && defaultVal!="" && defaultVal == select[0].options[i].value){
                                select[0].options[i].setAttribute('selected', 'selected');
                              }
                        }else{
                            select[0].options[i].style.display ="none";
                            select[0].options[i].removeAttribute('selected');
                        }
                       
                    }
                }
            }
        }
    }
}
function onDateChage(obj) {
    if (obj.value) {
        if (obj.value == null || obj.value == '') return;
        let date = new Date(obj.value);
        let dayOfWeek = date.getDay();
        let isWeekend = (dayOfWeek === 6) || (dayOfWeek === 0);
        if (isWeekend == true) {
            obj.value = null;
            alert("You cann't choose weekend ");
        }
    }
}

==> wordsonline_connector-2.0.0-alpha8.tar.gz: wordsonline_connector/js/job_form.js <==
function onContentTypeChange(obj) {

    if (obj) {
        let val = obj.value;
        let data = JSON.parse(obj.getAttribute("service-level-data"));
        let select = document.getElementsByName("settings[service_level]");
        if (select) {
            let defaultVal =select[0].getAttribute("default-value");
            const count = select[0].options.length;
            // for (let i = count - 1; i >= 0; i--) {
            //     select[0].options.remove(i);
            // }
            // let arr = [];
            // for (let index = 0; index < data.length; index++) {
            //     let element = data[index];
            //     if (element['contentType'] == val && arr.indexOf(element['serviceName']) < 0) {
            //         arr.push(element['serviceName']);
            //         var opt = document.createElement('option');
            //         opt.value = element['serviceName'];
            //         opt.innerHTML = element['serviceName'];
            //         if(defaultVal && defaultVal !=null && defaultVal!="" && defaultVal == opt.value){
            //           opt.setAttribute('selected', 'selected');
            //         }
            //         select[0].appendChild(opt);
            //     }
            // }
            for (let i = count - 1; i >= 0; i--) {
                for (let index = 0; index < data.length; index++) {
                    let element = data[index];
                    if (element['contentType'] == val) {
                        if(select[0].options[i].value == element['serviceName']){
                            select[0].options[i].style.display ="block";
                            if(defaultVal && defaultVal !=null && defaultVal!="" && defaultVal == select[0].options[i].value){
                                select[0].options[i].setAttribute('selected', 'selected');
                              }
                        }else{
                            select[0].options[i].style.display ="none";
                            select[0].options[i].removeAttribute('selected');
                        }
                       
                    }
                }
            }
        }
    }
}
function onDateChage(obj) {
    if (obj.value) {
        if (obj.value == null || obj.value == '') return;
        let date = new Date(obj.value);
        let dayOfWeek = date.getDay();
        let isWeekend = (dayOfWeek === 6) || (dayOfWeek === 0);
        if (isWeekend == true) {
            obj.value = null;
            alert("You can't choose weekend ");
        }
    }
}
function onChangeServiceLevel(obj){
     if (obj.value) {
        let input = document.getElementsByName("settings[service_level]");
        if(input){
          input[0].value = obj.value;
          input[0].dispatchEvent(new Event('change'));
        }
        
    }
}
